@@ -1,9 +1,10 @@
 from universalasync import wrap
 
-from .coins import BCH, BNB, BSTY, BTC, COINS, ETH, LTC, XRG  # noqa: F401
+from .coins import BCH, BNB, BTC, COINS, ETH, GRS, LTC, MATIC, TRX, XMR, XRG  # noqa: F401
 from .errors import errors
 from .manager import APIManager
 from .providers.jsonrpcrequests import RPCProxy
+from .version import VERSION
 
 # Make all types accessible via both sync and async contexts
 for coin in COINS.values():
@@ -11,4 +12,4 @@ for coin in COINS.values():
 wrap(APIManager)
 wrap(RPCProxy)
 
-__all__ = list(COINS.keys()) + ["APIManager", "COINS", "RPCProxy", "errors"]
+__all__ = list(COINS.keys()) + ["APIManager", "COINS", "RPCProxy", "errors", "VERSION"]
