@@ -1,11 +1,12 @@
-from typing import Callable, Dict, Optional
+from collections.abc import Callable
 
 
 class Coin:
     coin_name: str
+    xpub_name: str
     friendly_name: str
-    event_handlers: Dict[str, Callable]
-    xpub: Optional[str]
+    event_handlers: dict[str, Callable]
+    xpub: str | None
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, Coin):
