@@ -1,6 +1,7 @@
-from decimal import Decimal
+import inspect
+from collections.abc import Callable, Iterable
 from functools import wraps
-from typing import TYPE_CHECKING, Any, Callable, Dict, Iterable, Optional, Union
+from typing import TYPE_CHECKING, Any, Optional
 
 from ..coin import Coin
 from ..errors import LightningDisabledError
@@ -8,7 +9,7 @@ from ..event_delivery import EventDelivery
 from ..logger import logger
 from ..providers.jsonrpcrequests import RPCProxy
 from ..types import AmountType
-from ..utils import bitcoins, call_universal, convert_amount_type
+from ..utils import bitcoins, call_universal, convert_amount_type, satoshis
 
 if TYPE_CHECKING:
     from aiohttp import ClientSession, ClientWebSocketResponse
@@ -19,7 +20,8 @@ def lightning(f: Callable) -> Callable:
     async def wrapper(*args: Any, **kwargs: Any) -> Any:
         if len(args) > 0:
             obj = args[0]
-            if not await obj.get_config("lightning"):  # pragma: no cover: can't be changed during tests
+            capabilities = (await obj.spec).get("capabilities", {})
+            if not capabilities.get("lightning", False):  # pragma: no cover: can't be changed during tests
                 raise LightningDisabledError("Lightning is disabled in current daemon.")
         return await f(*args, **kwargs)
 
@@ -28,20 +30,24 @@ def lightning(f: Callable) -> Callable:
 
 class BTC(Coin, EventDelivery):
     coin_name = "BTC"
+    xpub_name = "Xpub"
     friendly_name = "Bitcoin"
     RPC_URL = "http://localhost:5000"
     RPC_USER = "electrum"
-    RPC_PASS = "electrumz"
+    RPC_PASS = "electrumz"  # noqa
     ALLOWED_EVENTS = ["new_block", "new_transaction", "new_payment", "verified_tx"]
     BALANCE_ATTRS = ["confirmed", "unconfirmed", "unmatured", "lightning"]
+    EXPIRATION_KEY = "expiry"
+    is_eth_based = False
+    additional_xpub_fields: list[str] = []
 
     def __init__(
         self,
-        rpc_url: Optional[str] = None,
-        rpc_user: Optional[str] = None,
-        rpc_pass: Optional[str] = None,
-        xpub: Optional[str] = None,
-        proxy: Optional[str] = None,
+        rpc_url: str | None = None,
+        rpc_user: str | None = None,
+        rpc_pass: str | None = None,
+        xpub: str | None = None,
+        proxy: str | None = None,
         session: Optional["ClientSession"] = None,
     ):
         super().__init__()
@@ -50,7 +56,7 @@ class BTC(Coin, EventDelivery):
         self.rpc_user = rpc_user or self.RPC_USER
         self.rpc_pass = rpc_pass or self.RPC_PASS
         self.xpub = xpub
-        self.event_handlers: Dict[str, Callable] = {}
+        self.event_handlers: dict[str, Callable] = {}
         self.amount_field = getattr(self, "AMOUNT_FIELD", f"amount_{self.coin_name}")
         self.server = RPCProxy(self.rpc_url, self.rpc_user, self.rpc_pass, self.xpub, session=session, proxy=proxy)
 
@@ -146,22 +152,24 @@ class BTC(Coin, EventDelivery):
     async def _add_request_base(
         self,
         method: Callable,
-        amount: Optional[AmountType] = None,
+        amount: AmountType | None = None,
         description: str = "",
-        expire: Union[int, float] = 15,
-        extra_kwargs: dict = {},
+        expire: int | float = 15,
+        extra_kwargs: dict | None = None,
     ) -> dict:
+        if extra_kwargs is None:  # pragma: no cover
+            extra_kwargs = {}
         expiration = 60 * expire if expire else None
-        kwargs = {"amount": amount, "memo": description, "expiration": expiration}
+        kwargs = {"amount": amount, "memo": description, self.EXPIRATION_KEY: expiration}
         kwargs.update(extra_kwargs)
         data = await method(**kwargs)
         return await self._convert_amounts(data)
 
     async def add_request(
         self,
-        amount: Optional[AmountType] = None,
+        amount: AmountType | None = None,
         description: str = "",
-        expire: Union[int, float] = 15,
+        expire: int | float = 15,
     ) -> dict:
         """Add invoice
 
@@ -201,7 +209,7 @@ class BTC(Coin, EventDelivery):
         Returns:
             dict: Invoice data
         """
-        data = await self.server.getrequest(address)
+        data = await self.server.get_request(address)
         return await self._convert_amounts(data)
 
     async def history(self) -> dict:
@@ -237,19 +245,23 @@ class BTC(Coin, EventDelivery):
                 continue
             handler = self.event_handlers.get(event)
             if handler:
+                handler_keys = inspect.signature(handler).parameters.keys()
                 args = (event,)
                 if pass_instance:
                     args = (self,) + args
+                for arg in event_info.copy():
+                    if arg not in handler_keys:
+                        event_info.pop(arg)
                 await call_universal(handler, *args, **event_info)
 
     async def pay_to(
         self,
         address: str,
         amount: AmountType,
-        fee: Optional[Union[AmountType, Callable]] = None,
-        feerate: Optional[AmountType] = None,
+        fee: AmountType | Callable | None = None,
+        feerate: AmountType | None = None,
         broadcast: bool = True,
-    ) -> Union[dict, str]:
+    ) -> dict | str:
         """Pay to address
 
         This function creates a transaction, your wallet must have sufficent balance
@@ -291,9 +303,9 @@ class BTC(Coin, EventDelivery):
         )
         if is_callable:
             tx_size = await self.server.get_tx_size(tx_data)
-            default_fee = await self.server.get_default_fee(tx_size)
+            default_fee = satoshis(await self.server.get_default_fee(tx_size))
             try:
-                resulting_fee: Optional[str] = str(bitcoins(fee(tx_size, default_fee)))  # type: ignore
+                resulting_fee: str | None = str(bitcoins(fee(tx_size, default_fee)))  # type: ignore
             except Exception:
                 resulting_fee = None
             if resulting_fee:
@@ -304,16 +316,15 @@ class BTC(Coin, EventDelivery):
                 await self.server.addtransaction(tx_data)
         if broadcast:
             return await self.server.broadcast(tx_data)  # type: ignore
-        else:
-            return tx_data  # type: ignore
+        return tx_data  # type: ignore
 
     async def pay_to_many(
         self,
-        outputs: Iterable[Union[dict, tuple]],
-        fee: Optional[Union[AmountType, Callable]] = None,
-        feerate: Optional[AmountType] = None,
+        outputs: Iterable[dict | tuple],
+        fee: AmountType | Callable | None = None,
+        feerate: AmountType | None = None,
         broadcast: bool = True,
-    ) -> Union[dict, str]:
+    ) -> dict | str:
         """Pay to multiple addresses(batch transaction)
 
         This function creates a batch transaction, your wallet must have sufficent balance
@@ -369,9 +380,9 @@ class BTC(Coin, EventDelivery):
         )
         if is_callable:
             tx_size = await self.server.get_tx_size(tx_data)
-            default_fee = await self.server.get_default_fee(tx_size)
+            default_fee = satoshis(await self.server.get_default_fee(tx_size))
             try:
-                resulting_fee: Optional[str] = str(bitcoins(fee(tx_size, default_fee)))  # type: ignore
+                resulting_fee: str | None = str(bitcoins(fee(tx_size, default_fee)))  # type: ignore
             except Exception:
                 resulting_fee = None
             if resulting_fee:
@@ -380,48 +391,7 @@ class BTC(Coin, EventDelivery):
                 await self.server.addtransaction(tx_data)
         if broadcast:
             return await self.server.broadcast(tx_data)  # type: ignore
-        else:
-            return tx_data  # type: ignore
-
-    async def rate(self, currency: str = "USD") -> Decimal:
-        """Get bitcoin price in selected fiat currency
-
-        It uses the same method as electrum wallet gets exchange rate-via different payment providers
-
-        Examples:
-
-        >>> c.rate()
-        9878.527
-
-        >>> c.rate("RUB")
-        757108.226
-
-        Args:
-            self (BTC): self
-            currency (str, optional): Currency to get rate into. Defaults to "USD".
-
-        Returns:
-            Decimal: price of 1 bitcoin in selected fiat currency
-        """
-        return convert_amount_type(await self.server.exchange_rate(currency))
-
-    async def list_fiat(self) -> Iterable[str]:
-        """List of all available fiat currencies to get price for
-
-        This list is list of only valid currencies that could be passed to rate() function
-
-        Example:
-
-        >>> c.list_fiat()
-        ['AED', 'ARS', 'AUD', 'BCH', 'BDT', 'BHD', 'BMD', 'BNB', 'BRL', 'BTC', ...]
-
-        Args:
-            self (BTC): self
-
-        Returns:
-            Iterable[str]: list of available fiat currencies
-        """
-        return await self.server.list_currencies()  # type: ignore
+        return tx_data  # type: ignore
 
     async def set_config(self, key: str, value: Any) -> bool:
         """Set config key to specified value
@@ -447,10 +417,9 @@ class BTC(Coin, EventDelivery):
         """
         return await self.server.setconfig(key, value)  # type: ignore
 
-    async def get_config(self, key: str, default: Any = None) -> Any:
+    async def get_config(self, key: str) -> Any:
         """Get config key
 
-        If the key doesn't exist, default value is returned.
         Keys are stored in electrum's config file, check :meth:`bitcart.coins.btc.BTC.set_config` doc for details.
 
         Example:
@@ -466,9 +435,9 @@ class BTC(Coin, EventDelivery):
         Returns:
             Any: value of the key or default value provided
         """
-        return await self.server.getconfig(key) or default
+        return await self.server.getconfig(key)
 
-    async def validate_key(self, key: str) -> bool:
+    async def validate_key(self, key: str, *args: Any, **kwargs: Any) -> bool:
         """Validate whether provided key is valid to restore a wallet
 
         If the key is x/y/z pub/prv or electrum seed at the network daemon is running
@@ -492,7 +461,7 @@ class BTC(Coin, EventDelivery):
         Returns:
             bool: Whether the key is valid or not
         """
-        return await self.server.validatekey(key)  # type: ignore
+        return await self.server.validatekey(key, *args, **kwargs)  # type: ignore
 
     ### Lightning apis ###
 
@@ -518,7 +487,7 @@ class BTC(Coin, EventDelivery):
         self,
         amount: AmountType,
         description: str = "",
-        expire: Union[int, float] = 15,
+        expire: int | float = 15,
     ) -> dict:
         """Create a lightning invoice
 
@@ -539,7 +508,9 @@ class BTC(Coin, EventDelivery):
         Returns:
             dict: Invoice data
         """
-        return await self._add_request_base(self.server.add_lightning_request, amount, description, expire)
+        return await self._add_request_base(
+            self._add_request, amount, description, expire, extra_kwargs={"force": True, "lightning": True}
+        )
 
     @lightning
     async def close_channel(self, channel_id: str, force: bool = False) -> str:
@@ -557,7 +528,7 @@ class BTC(Coin, EventDelivery):
         """
         return await self.server.close_channel(channel_id, force)  # type: ignore
 
-    @property  # type: ignore
+    @property
     @lightning
     async def node_id(self) -> str:
         """Get node id
@@ -641,7 +612,7 @@ class BTC(Coin, EventDelivery):
         Example:
 
         >>> c.get_invoice("e34d7fb4cda66e0760fc193496c302055d0fd960cfd982432355c8bfeecd5f33")
-        {'is_lightning': True, 'amount_BTC': Decimal('0.5'), 'timestamp': 1619273042, 'expiration': 900, ...
+        {'is_lightning': True, 'amount_BTC': Decimal('0.5'), 'timestamp': 1619273042, 'expiry': 900, ...
 
         Args:
             rhash (str): invoice rhash
