@@ -1,6 +1,7 @@
 import asyncio
+from collections.abc import Callable, Iterable
 from functools import partial
-from typing import TYPE_CHECKING, Any, Callable, Dict, Iterable, Optional
+from typing import TYPE_CHECKING, Any
 from urllib.parse import urljoin
 
 from bitcart.errors import CurrencyUnsupportedError, NoCurrenciesRegisteredError
@@ -18,24 +19,27 @@ if TYPE_CHECKING:
 
 
 class APIManager(EventDelivery):
-    def __init__(self, wallets: Dict[str, Iterable[str]] = {}):
+    def __init__(self, wallets: dict[str, Iterable[str]] | None = None, custom_params: dict[str, dict] | None = None):
+        if custom_params is None:
+            custom_params = {}
+        if wallets is None:
+            wallets = {}
         super().__init__()
+        self.custom_params = custom_params
         self.wallets = ExtendedDefaultDict(
             lambda: ExtendedDict(),
             {currency: self.load_wallets(currency, wallets) for currency, wallets in wallets.items()},
         )
         self.event_handlers = {}
 
-    @classmethod
-    def load_wallets(cls, currency: str, wallets: Iterable[str]) -> ExtendedDict:
-        return ExtendedDict({wallet: cls.load_wallet(currency, wallet) for wallet in wallets})
+    def load_wallets(self, currency: str, wallets: Iterable[str]) -> ExtendedDict:
+        return ExtendedDict({wallet: self.load_wallet(currency, wallet) for wallet in wallets})
 
-    @classmethod
-    def load_wallet(cls, currency: str, wallet: Optional[str] = None) -> "Coin":
+    def load_wallet(self, currency: str, wallet: str | None = None) -> "Coin":
         currency = currency.upper()
         if currency not in COINS:
             raise CurrencyUnsupportedError()
-        return COINS[currency](xpub=wallet)
+        return COINS[currency](xpub=wallet, **self.custom_params.get(currency, {}))
 
     def add_wallet(self, currency: str, wallet: str) -> None:
         self.wallets[currency][wallet] = self.load_wallet(currency, wallet)
@@ -62,7 +66,7 @@ class APIManager(EventDelivery):
             coin = self.load_wallet(currency, None)
         return coin.server  # type: ignore
 
-    async def _start_websocket_for_currency(self, currency: str, reconnect_callback: Optional[Callable] = None) -> None:
+    async def _start_websocket_for_currency(self, currency: str, reconnect_callback: Callable | None = None) -> None:
         if reconnect_callback:
             reconnect_callback = partial(reconnect_callback, currency)
         server = self._get_websocket_server(currency)
@@ -72,7 +76,7 @@ class APIManager(EventDelivery):
     async def start_websocket_for_currency(
         self,
         currency: str,
-        reconnect_callback: Optional[Callable] = None,
+        reconnect_callback: Callable | None = None,
         force_connect: bool = False,
         auto_reconnect: bool = True,
     ) -> None:
@@ -84,7 +88,7 @@ class APIManager(EventDelivery):
         )
 
     async def start_websocket(
-        self, reconnect_callback: Optional[Callable] = None, force_connect: bool = False, auto_reconnect: bool = True
+        self, reconnect_callback: Callable | None = None, force_connect: bool = False, auto_reconnect: bool = True
     ) -> None:
         tasks = []
         for currency in self.wallets:
@@ -97,9 +101,7 @@ class APIManager(EventDelivery):
         if not tasks:
             raise NoCurrenciesRegisteredError()
 
-    async def process_updates(
-        self, updates: Iterable[dict], currency: Optional[str] = None, wallet: Optional[str] = None
-    ) -> None:
+    async def process_updates(self, updates: Iterable[dict], currency: str | None = None, wallet: str | None = None) -> None:
         wallet_obj = self.wallets[currency].get(wallet)
         if not wallet_obj:
             try:
