@@ -1,19 +1,20 @@
 import inspect
 import json
 import traceback
+from collections.abc import Callable
 from decimal import Decimal
-from typing import Any, Callable
+from typing import Any
 
 from .logger import logger
 
 CONVERT_RATE = 100000000
 
 
-def convert_amount_type(amount: str) -> Decimal:
+def convert_amount_type(amount: str | Decimal) -> Decimal:
     """Convert amount from str to Decimal
 
     Args:
-        amount (str): amount
+        amount (Union[str, Decimal]): amount
 
     Returns:
         Decimal
@@ -23,16 +24,16 @@ def convert_amount_type(amount: str) -> Decimal:
     return Decimal(amount)
 
 
-def satoshis(amount: Decimal) -> int:
+def satoshis(amount: str | Decimal) -> int:
     """Convert amount from bitcoins to satoshis
 
     Args:
-        amount (Decimal): bitcoin amount
+        amount (Union[str, Decimal]): bitcoin amount
 
     Returns:
         int: same amount in satoshis
     """
-    return int(amount * CONVERT_RATE)
+    return int(convert_amount_type(amount) * CONVERT_RATE)
 
 
 def bitcoins(amount: int) -> Decimal:
