@@ -1,10 +1,11 @@
+import os
 from decimal import Decimal
 
 import pytest
 
-from bitcart import errors
+from bitcart import BTC, errors
 
-from ...utils import data_check
+from ...utils import assert_contains, data_check
 
 pytestmark = pytest.mark.asyncio
 
@@ -19,8 +20,8 @@ async def test_balance(btc_wallet):
 
 async def test_history(btc_wallet):
     history = await btc_wallet.history()
-    data_check(history, "summary", dict)
-    data_check(history, "transactions", list, 0)
+    assert isinstance(history, list)
+    assert len(history) == 0
 
 
 async def test_payment_request(btc_wallet):
@@ -34,25 +35,26 @@ async def test_payment_request(btc_wallet):
     assert request2["amount_BTC"] == Decimal(request2_amount)
     assert request2["message"] == request2_desc
     # get request2
-    response2 = await btc_wallet.get_request(request2["address"])
+    response2 = await btc_wallet.get_request(request2["request_id"])
     assert response2["amount_BTC"] == Decimal(request2_amount)
     assert response2["message"] == request2_desc
     # full data structure check
-    assert (
-        request1.items()
-        > {
+    assert_contains(
+        {
             "is_lightning": False,
             "amount_BTC": Decimal("0.5"),
             "message": "",
-            "expiration": 900,
             "status": 0,
-            "status_str": "Expires in 15 minutes",
+            "status_str": "Expires in about 15 minutes",
             "amount_sat": 50000000,
-        }.items()
+        },
+        request1,
     )
     data_check(request1, "timestamp", int)
+    data_check(request1, "expiry", int)
     data_check(request1, "address", str)
     data_check(request1, "URI", str)
+    assert request1["expiry"] == 900
 
 
 async def test_insufficient_funds_pay(btc_wallet):
@@ -69,3 +71,12 @@ async def test_fee_and_feerate(btc_wallet):  # can't set both fee and feerate
             fee=1,
             feerate=1,
         )
+
+
+async def test_diskless_mode(btc_wallet):
+    seed = await btc_wallet.server.make_seed()
+    filename = os.path.join((await btc_wallet.server.getinfo())["path"], "wallets", seed)
+    assert not os.path.exists(filename)
+    coin = BTC(xpub={"xpub": seed, "diskless": True})
+    await coin.help()
+    assert not os.path.exists(filename)
