@@ -1,3 +1,4 @@
+import asyncio
 import socket
 
 import pytest
@@ -37,6 +38,11 @@ async def btc_wallet():
     return BTC(xpub=TEST_XPUB)
 
 
+@pytest.fixture
+async def btc_wallet_lightning():
+    return BTC(xpub=REGTEST_XPUB)
+
+
 @pytest.fixture
 async def lightning_unsupported_wallet():
     return BTC(xpub=LIGHTNING_UNSUPPORTED_XPUB)
@@ -83,8 +89,7 @@ class FakeResolver:
                     "flags": socket.AI_NUMERICHOST,
                 }
             ]
-        else:
-            return await self._resolver.resolve(host, port, family)
+        return await self._resolver.resolve(host, port, family)
 
 
 class FakeDaemon:
@@ -108,6 +113,7 @@ class FakeDaemon:
         ws = web.WebSocketResponse()
         await ws.prepare(request)
         await self.reply_to_websocket(ws)
+        await asyncio.sleep(0.5)  # because events are processed asynchronously
         await ws.close()
 
     async def reply_to_websocket(self, ws):
