@@ -131,7 +131,6 @@ async def test_list_peers(regtest_wallet, regtest_node_id):  # running on regtes
     assert peer["node_id"] == regtest_node_id.split("@")[0]
     data_check(peer, "address", str)
     data_check(peer, "features", str)
-    assert "LnFeatures." in peer["features"]
     data_check(peer, "channels", list, 0)
 
 
@@ -162,7 +161,7 @@ async def test_list_channels(regtest_wallet, regtest_node_id):
 async def test_lnpay(regtest_wallet, regtest_node):
     with pytest.raises(errors.InvalidLightningInvoiceError):
         assert not await regtest_wallet.lnpay("")
-    invoice = (await regtest_node.add_invoice(0.01))["invoice"]
+    invoice = (await regtest_node.add_invoice(0.01))["lightning_invoice"]
     response = await regtest_wallet.lnpay(invoice)
     assert isinstance(response, dict)
     assert response.keys() == {"payment_hash", "success", "preimage", "log"}
